@extends('admin.layout.default')
@section('content')
    <div class="page-content">
        <div class="container-fluid">
            <div class="d-flex justify-content-between align-items-center mb-3">
                <h5 class="text-uppercase">{{ trans('labels.add_plan') }}</h5>
                <nav aria-label="breadcrumb">
                    <ol class="breadcrumb">
                        <li class="breadcrumb-item"><a href="{{ URL::to('admin/plans') }}">{{ trans('labels.plans') }}</a>
                        </li>
                        <li class="breadcrumb-item active" aria-current="page">{{ trans('labels.add') }}</li>
                    </ol>
                </nav>
            </div>
            <div class="row">
                <div class="col-12">
                    <div class="card border-0 box-shadow">
                        <div class="card-body">
                            <form action="{{ URL::to('admin/plans/store') }}" method="POST">
                                @csrf
                                <div class="row">
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.name') }}</label>
                                        <input type="text" class="form-control" name="plan_name"
                                            value="{{ old('plan_name') }}" placeholder="{{ trans('labels.name') }}">
                                        @error('plan_name')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.price') }}</label>
                                        <input type="number" class="form-control" name="plan_price"
                                            value="{{ old('plan_price') }}" placeholder="{{ trans('labels.price') }}">
                                        @error('plan_price')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.duration') }}</label>
                                        <select class="form-select" name="plan_duration">
                                            <option value="1" {{ old('plan_duration') == '1' ? 'selected' : '' }}>
                                                {{ trans('labels.one_month') }}</option>
                                            <option value="2" {{ old('plan_duration') == '2' ? 'selected' : '' }}>
                                                {{ trans('labels.three_months') }}</option>
                                            <option value="3" {{ old('plan_duration') == '3' ? 'selected' : '' }}>
                                                {{ trans('labels.six_months') }}</option>
                                            <option value="4" {{ old('plan_duration') == '4' ? 'selected' : '' }}>
                                                {{ trans('labels.one_year') }}</option>
                                        </select>
                                        @error('plan_duration')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.max_business') }}</label>
                                        <input type="number" class="form-control" name="plan_max_business"
                                            value="{{ old('plan_max_business') }}"
                                            placeholder="{{ trans('labels.max_business') }}">
                                        <small class="form-text text-danger fs-8">{{ trans('labels.note_unlimited') }}</small><br>
                                        @error('plan_max_business')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.appointment_limit') }}</label>
                                        <input type="number" class="form-control" name="plan_appointment_limit"
                                            value="{{ old('plan_appointment_limit') }}"
                                            placeholder="{{ trans('labels.appointment_limit') }}">
                                        <small class="form-text text-danger fs-8">{{ trans('labels.note_unlimited') }}</small><br>
                                        @error('plan_appointment_limit')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.service_limit') }}</label>
                                        <input type="number" class="form-control" name="plan_service_limit"
                                            value="{{ old('plan_service_limit') }}"
                                            placeholder="{{ trans('labels.service_limit') }}">
                                        <small class="form-text text-danger fs-8">{{ trans('labels.note_unlimited') }}</small><br>
                                        @error('plan_service_limit')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.video_limit') }}</label>
                                        <input type="number" class="form-control" name="plan_video_limit"
                                            value="{{ old('plan_video_limit') }}"
                                            placeholder="{{ trans('labels.video_limit') }}">
                                        <small class="form-text text-danger fs-8">{{ trans('labels.note_unlimited') }}</small><br>
                                        @error('plan_video_limit')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.testimonial_limit') }}</label>
                                        <input type="number" class="form-control" name="plan_testimonial_limit"
                                            value="{{ old('plan_testimonial_limit') }}"
                                            placeholder="{{ trans('labels.testimonial_limit') }}">
                                        <small class="form-text text-danger fs-8">{{ trans('labels.note_unlimited') }}</small><br>
                                        @error('plan_testimonial_limit')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.description') }}</label>
                                        <textarea class="form-control" rows="3" name="plan_description" placeholder="{{ trans('labels.description') }}">{{ old('plan_description') }}</textarea>
                                        @error('plan_description')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="col-sm-6 form-group">
                                        <label class="form-label">{{ trans('labels.features') }}</label>
                                        <div id="repeater">
                                            <div class="d-flex mb-2">
                                                <input type="text" class="form-control" name="plan_features[]"
                                                    value="{{ old('plan_features[1]') }}"
                                                    placeholder="{{ trans('labels.features') }}">
                                                <button type="button" class="btn btn-outline-secondary mx-2 btn-sm"
                                                    id="addfeature">
                                                    <i class="fa-regular fa-plus"></i>
                                                </button>
                                            </div>
                                        </div>
                                        @error('plan_features')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                    </div>
                                    <div class="form-group">
                                        <h5 class="form-label mb-3">{{ trans('labels.select_themes') }}</h5>
                                        @error('themecheckbox')
                                            <small class="text-danger">{{ $message }}</small>
                                        @enderror
                                        <ul class="theme-selection">
                                            <li>
                                                <input type="checkbox" name="themecheckbox[]" id="theme1" value="1"
                                                    {{ is_array(old('themecheckbox')) && in_array(1, old('themecheckbox')) ? 'checked' : '' }}>
                                                <label for="theme1">
                                                    <img
                                                        src="{{ url('storage/admin-assets/images/themes/1.jpg') }}">
                                                </label>
                                            </li>
                                            <li>
                                                <input type="checkbox" name="themecheckbox[]" id="theme2" value="2"
                                                    {{ is_array(old('themecheckbox')) && in_array(2, old('themecheckbox')) ? 'checked' : '' }}>
                                                <label for="theme2">
                                                    <img
                                                        src="{{ url('storage/admin-assets/images/themes/2.jpg') }}">
                                                </label>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                                <button class="btn btn-secondary mt-4"
                                    @if (env('Environment') == 'sendbox') type="button" onclick="myFunction()" @else type="submit" @endif>{{ trans('labels.submit') }}</button>
                            </form>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
@endsection
@section('scripts')
    <script>
        var i = 1;
        $("#addfeature").on('click', function() {
            "use strict";
            var html =
                '<div class="d-flex mb-2" id="removediv' + i +
                '"><input type="text" class="form-control" name="plan_features[]" value="{{ old('plan_features[]') }}" placeholder="{{ trans('labels.features') }}" required><button type="button" class="btn btn-danger mx-2 btn-sm" onclick="removefeature(' +
                i + ')"><i class="fa-regular fa-xmark"></i></button></div>';
            $("#repeater").append(html);
            i++;
        })

        function removefeature(id) {
            "use strict";
            $('#removediv' + id).remove();
        }
    </script>
@endsection
